@@ -1,26 +1,26 @@
-from typing import Optional, List
+from typing import Optional, List, Tuple
 from parchmint.params import Params
 from parchmint.port import Port
 from parchmint.layer import Layer
 
-class Component:
 
+class Component:
     def __init__(self, json=None):
         self.name: Optional[str] = None
         self.ID: Optional[str] = None
         self.params = Params()
-        self.entity: Optional[str] = None
-        self.xpos: Optional[int] = None
-        self.ypos: Optional[int] = None
-        self.xspan: Optional[int] = None
-        self.yspan: Optional[int] = None
+        self.entity: str = ""
+        self.xpos: int = -1
+        self.ypos: int = -1
+        self.xspan: int = -1
+        self.yspan: int = -1
         self.ports: List[Port] = []
         self.layers: List[Layer] = []
 
         if json:
             self.parse_from_json(json)
 
-    def add_component_ports(self, ports:List[Port]) -> None:
+    def add_component_ports(self, ports: List[Port]) -> None:
         for port in ports:
             self.ports.append(port)
 
@@ -28,8 +28,8 @@ class Component:
         self.name = json["name"]
         self.ID = json["id"]
         self.entity = json["entity"]
-        self.xspan = json["xspan"]
-        self.yspan = json["yspan"]
+        self.xspan = json["x-span"]
+        self.yspan = json["y-span"]
         self.params = Params(json["params"])
         self.layers = json["layers"]
 
@@ -63,3 +63,15 @@ class Component:
             return obj.ID == self.ID
         else:
             return False
+
+    def get_port(self, label: str) -> Port:
+        for port in self.ports:
+            if label == port.label:
+                return port
+        raise Exception("Could not find port with the label: {}".format(label))
+
+    def get_absolute_port_coordinates(self, port_label: str) -> Tuple[float, float]:
+        port = self.get_port(port_label)
+        x = self.xpos + port.x
+        y = self.ypos + port.y
+        return (x, y)
