@@ -3,7 +3,6 @@ from parchmint.params import Params
 
 
 class Layer:
-
     def __init__(self, json=None) -> None:
         self.ID: Optional[str] = None
         self.name: Optional[str] = None
@@ -32,3 +31,9 @@ class Layer:
 
     def __repr__(self):
         return str(self.__dict__)
+
+    def __eq__(self, o: object) -> bool:
+        if isinstance(o, Layer):
+            return o.ID == self.ID
+        else:
+            return False
